package com.ruoyi.kaohe.service;

import java.util.List;
import com.ruoyi.kaohe.domain.KhUidRecard;

/**
 * uid管理Service接口
 * 
 * @author hs
 * @date 2025-07-02
 */
public interface IKhUidRecardService 
{
    /**
     * 查询uid管理
     * 
     * @param id uid管理主键
     * @return uid管理
     */
    public KhUidRecard selectKhUidRecardById(Long id);

    /**
     * 查询uid管理列表
     * 
     * @param khUidRecard uid管理
     * @return uid管理集合
     */
    public List<KhUidRecard> selectKhUidRecardList(KhUidRecard khUidRecard);

    /**
     * 新增uid管理
     * 
     * @param khUidRecard uid管理
     * @return 结果
     */
    public int insertKhUidRecard(KhUidRecard khUidRecard);

    /**
     * 修改uid管理
     * 
     * @param khUidRecard uid管理
     * @return 结果
     */
    public int updateKhUidRecard(KhUidRecard khUidRecard);

    /**
     * 批量删除uid管理
     * 
     * @param ids 需要删除的uid管理主键集合
     * @return 结果
     */
    public int deleteKhUidRecardByIds(Long[] ids);

    /**
     * 删除uid管理信息
     * 
     * @param id uid管理主键
     * @return 结果
     */
    public int deleteKhUidRecardById(Long id);
}
